translate.storage.placeables.xliff.UnknownXML

Package translate :: Package storage :: Package placeables :: Module xliff :: Class UnknownXML |
[hide private]
[frames] | no frames]

# Class UnknownXML

source code

Placeable for unrecognized or umimplemented XML nodes. It's main purpose is to preserve all associated XML data.

Instance Methods | [hide private]
__init__(self, sub=None, id=None, rid=None, xid=None, xml_node=None, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__repr__(self) String representation of the sub-tree with the current node as the root. | source code
copy(self) Returns a copy of the sub-tree. | source code
Inherited from `strelem.StringElem`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getitem__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__radd__`, `__rmul__`, `__str__`, `__unicode__`, `apply_to_strings`, `delete_elem`, `delete_range`, `depth_first`, `elem_at_offset`, `elem_offset`, `encode`, `find`, `find_elems_with`, `flatten`, `get_ancestor_where`, `get_index_data`, `get_parent_elem`, `insert`, `insert_between`, `isleaf`, `iter_depth_first`, `map`, `print_tree`, `prune`, `remove_type`, `translate` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `strelem.StringElem`: `parse`

Class Variables | [hide private]
| iseditable = `True` Whether this string should be changable by the user.
Inherited from `strelem.StringElem`: `has_content`, `isfragile`, `istranslatable`, `isvisible`, `renderer`, `sub`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, sub=None, id=None, rid=None, xid=None, xml_node=None, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
String representation of the sub-tree with the current node as the root. Copied from StringElem.__repr__, but includes `self.xml_node.tag`. Overrides: object.__repr__

### copy(self) | source code
Returns a copy of the sub-tree. This should be overridden in sub-classes with more data. NOTE: `self.renderer` is not copied. Overrides: strelem.StringElem.copy